# Examples

You can use your favorite window with ModernGL.

> Missing?<br>Write an [issue](https://github.com/cprogrammer1994/ModernGL/issues).

If you use ModernGL with a different window or you have an awesome example then please share it!

## Requirements

The examples depend on other modules please read the README files in the subfolders.

Most of the examples depend on the following modules:

- ModernGL _(obviously)_
- Pyrr _(matrix multiplication)_
- Pillow _(loading textures)_
- numpy _(working with arrays)_

It is reccommanded to install these before running the examples.

```sh
pip install ModernGL Pyrr Pillow numpy
```

Don't forget to install the module for window support.
Only one per subfolder is enough but you can install all of them with the following commands.

```sh
pip install PyQt5
pip install pyglet
pip install pygame
pip install kivy kivy.deps.sdl2 kivy.deps.glew
pip install PyOpenGL PyOpenGL_accelerate
pip install GLWindow
pip install PySDL2
```

## Contents

- [GLUT](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLUT)
  - [01_hello_world](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLUT/01_hello_world.py)
  - [02_uniforms_and_attributes](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLUT/02_uniforms_and_attributes.py)
  - [03_alpha_blending](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLUT/03_alpha_blending.py)
  - [04_textures](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLUT/04_textures.py)
  - [perspective_projection](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLUT/perspective_projection.py)
  - [window_coordinates](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLUT/window_coordinates.py)

- [GLWindow](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow)
  - [01_hello_world](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/01_hello_world.py)
  - [02_uniforms_and_attributes](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/02_uniforms_and_attributes.py)
  - [03_alpha_blending](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/03_alpha_blending.py)
  - [04_textures](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/04_textures.py)
  - [05_perspective_projection](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/05_perspective_projection.py)
  - [05_perspective_projection_using_numpy](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/05_perspective_projection_using_numpy.py)
  - [julia_fractal](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/julia_fractal.py)
  - [particle_system](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/particle_system.py)
  - [particle_system_2](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/particle_system_2.py)
  - [pillow_font](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/pillow_font.py)
  - [using_texture3d](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/using_texture3d.py)
  - [perspective_projection](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/perspective_projection.py)
  - [window_coordinates](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/GLWindow/window_coordinates.py)

- [Kivy](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/Kivy)
  - [01_hello_world](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/Kivy/01_hello_world.py)
  - [perspective_projection](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/Kivy/perspective_projection.py)
  - [window_coordinates](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/Kivy/window_coordinates.py)

- [pygame](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pygame)
  - [01_hello_world](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pygame/01_hello_world.py)
  - [perspective_projection](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pygame/perspective_projection.py)
  - [window_coordinates](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pygame/window_coordinates.py)

- [pyglet](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pyglet)
  - [01_hello_world](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pyglet/01_hello_world.py)
  - [02_uniforms_and_attributes](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pyglet/02_uniforms_and_attributes.py)
  - [03_alpha_blending](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pyglet/03_alpha_blending.py)
  - [04_textures](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pyglet/04_textures.py)
  - [perspective_projection](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pyglet/perspective_projection.py)
  - [window_coordinates](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/pyglet/window_coordinates.py)

- [PyQt5](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/PyQt5)
  - [01_hello_world](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/PyQt5/01_hello_world.py)
  - [02_uniforms_and_attributes](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/PyQt5/02_uniforms_and_attributes.py)
  - [03_alpha_blending](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/PyQt5/03_alpha_blending.py)
  - [04_textures](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/PyQt5/04_textures.py)
  - [05_perspective_projection](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/PyQt5/05_perspective_projection.py)
  - [perspective_projection](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/PyQt5/perspective_projection.py)
  - [window_coordinates](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/PyQt5/window_coordinates.py)

- [PyQt5](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/PySDL2)
  - soon

- [tkinter](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/tkinter)
  - [01_hello_world](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/tkinter/01_hello_world.py)
  - [colors](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/tkinter/colors.py)

- [standalone](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/standalone)
  - [01_hello_world](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/standalone/01_hello_world.py)
  - [render_to_pillow_image](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/standalone/render_to_pillow_image.py)
  - [render_to_pillow_image_multisample](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/standalone/render_to_pillow_image_multisample.py)
  - [perspective_projection](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/standalone/perspective_projection.py)
  - [window_coordinates](https://github.com/cprogrammer1994/ModernGL/tree/master/examples/standalone/window_coordinates.py)

## Images

### Basic

<img width="50%" src="https://raw.githubusercontent.com/cprogrammer1994/ModernGL/master/docs/Examples/images/01_hello_world.png">

<img width="50%" src="https://raw.githubusercontent.com/cprogrammer1994/ModernGL/master/docs/Examples/images/02_uniforms_and_attributes.png">

<img width="50%" src="https://raw.githubusercontent.com/cprogrammer1994/ModernGL/master/docs/Examples/images/03_alpha_blending.png">

<img width="50%" src="https://raw.githubusercontent.com/cprogrammer1994/ModernGL/master/docs/Examples/images/04_textures.png">

### julia_fractal

<img width="50%" src="https://raw.githubusercontent.com/cprogrammer1994/ModernGL/master/docs/Examples/images/julia_fractal.png">

### particle_system

<img width="50%" src="https://raw.githubusercontent.com/cprogrammer1994/ModernGL/master/docs/Examples/images/particle_system.png">
